Documentation
=============

`Cosmo-Utils <https://github.com/vcalderon2009/cosmo_utils>`_ is a package 
used in many of my projects related to LSS (large-scale structure), 
astrophysics, and the `Sloan Digital Sky Survey <http://www.sdss.org/>`_.

The source code is freely availabe at
`https://github.com/vcalderon2009/cosmo_utils <https://github.com/vcalderon2009/cosmo_utils>`_.

|Astropy| |PyPI| |Travis_Build| |Issues| |RTD| |Coverage| |License|

Getting Started
===============

.. toctree::
   :maxdepth: 1

   install

What's New?
===========

.. toctree::
   :maxdepth: 1

   whats_new
   changelog


Reference
=========

.. toctree::
   :maxdepth: 1

   full_ref_api/cosmo_utils_full_api


.. |Astropy| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. |Release| image:: https://img.shields.io/github/release/vcalderon2009/cosmo_utils.svg
   :target: https://github.com/vcalderon2009/cosmo_utils/releases/latest
   :alt: Latest Release

.. |PyPI| image:: https://img.shields.io/pypi/v/cosmo-utils.svg
   :target: https://pypi.python.org/pypi/cosmo-utils
   :alt: PyPI Release

.. |Travis_Build| image:: https://travis-ci.org/vcalderon2009/cosmo_utils.svg?branch=master
   :target: https://travis-ci.org/vcalderon2009/cosmo_utils
   :alt: Build Status

.. |Issues| image:: https://img.shields.io/github/issues/vcalderon2009/cosmo_utils.svg
   :target: https://github.com/vcalderon2009/cosmo_utils/issues
   :alt: Open Issues

.. |RTD| image:: https://readthedocs.org/projects/cosmo-utils/badge/?version=latest
   :target: http://cosmo-utils.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. |Coverage| image:: https://coveralls.io/repos/github/vcalderon2009/cosmo_utils/badge.svg?branch=master
   :target: https://coveralls.io/github/vcalderon2009/cosmo_utils?branch=master
   :alt: Coveralls Status

.. |License| image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://opensource.org/licenses/BSD-3-Clause
   :alt: Project License 